==> deepin-screen-recorder_5.10.15.orig.tar.xz: deepin-screen-recorder-5.10.15/translations/deepin-screen-recorder_lv.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lv">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Noklikšķiniet uz ikonas
vai vēlreiz nospiediet saīsni, lai pārtrauktu ierakstīšanu</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Nerotējiet ekrānu ieraksta laikā</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Ierakstīt</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekrānuzņēmums</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Ekrāna ierakstīšana</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Saglabāšana neizdevās. Lūzu saglabājiet mājas mapē</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Apskatīt</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Ekrāna uzņēmums izveidots</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>izvēlēties-laukumu</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Saglabāt</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Saglabāt %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorēt</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Starpliktuve</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Saglabā ekrāna ierakstu, lūdzu uzgaidiet...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Tā kā procesa laikā loga efekts ir atspējots, ieraksts ir jāpārtrauc</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekrānuzņēmums</translation>
    </message>
    <message>
        <source>The screenshot has been saved in the album</source>
        <translation>Ekrānuzņēmums saglabāts albumā</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Atsaukt</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Saglabāt</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Iziet</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Apskatīt</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Ieraksts pabeigts</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Saglabāt %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Ierakstīt</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Ekrāna ierakstīšana sāksies pēc %1 sekundēm</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Ievadiet tekstu šeit</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Sākt/Ekrānuzņēmums</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Iziet/Saglabāt</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Pielāgot izmēru</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Iestatījumi</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Ātrais sākums</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Loga ekrānuzņēmums</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Atlikt ekrānuzņēmumu</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Viss ekrānuzņēmums</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Iziet</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Saglabāt</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Taisnstūris</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Līnija</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Zīmulis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Teksts</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dzēst</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Atsaukt</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Palielināt augstumu augšā</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Palielināt augstumu lejā</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Palielināt platumu kreisajā pusē</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Palielināt platumu labajā pusē</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Samazināt augstumu augšā</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Samazināt augstumu lejā</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Samazināt platumu kreisajā pusē</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Samazināt platumu labajā pusē</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Palīdzība</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Rādīt saīsnes</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Skaņa</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Taustiņa nospiešana</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Sākt ierakstu</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Iestatījumi</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Sākt/Ierakstīt</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Pele</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Izpludināt</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mozaīka</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Ieslēgt skaņu</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofons</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Sistēmas skaņa</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Izslēgt skaņu</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Rādīt taustiņu nospiešanu</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Nerādīt taustiņu nospiešanu</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Ieslēgt kameru</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Izslēgt kameru</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Rādīt klikšķus</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Iestatījumi</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formāts:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>Kadri sekundē:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 kadri sekundē</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 kadri sekundē</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 kadri sekundē</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 kadri sekundē</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 kadri sekundē</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Taisnstūris</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Līnija</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Bulta</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Zīmulis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Teksts</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Saglabāt</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Darbavirsma</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Attēli</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mape</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formāts</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Starpliktuve</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Rādīt rādītāju</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Pele</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Rādīt Rādītāju</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>Atzimējiet ieraksta laukumu iekļaujoties %1*%2 lai iegūtu labāku video</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation>Iziet</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.11.21.orig.tar.xz: deepin-screen-recorder-5.11.21/translations/deepin-screen-recorder_lv.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lv">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Noklikšķiniet uz ikonas
vai vēlreiz nospiediet saīsni, lai pārtrauktu ierakstīšanu</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Nerotējiet ekrānu ieraksta laikā</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Ekrānuzņēmums</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Ierakstīt</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekrānuzņēmums</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Ekrāna ierakstīšana</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Saglabāšana neizdevās. Lūzu saglabājiet mājas mapē</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Apskatīt</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Ekrāna uzņēmums izveidots</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>izvēlēties-laukumu</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Saglabāt</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Saglabāt %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorēt</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Starpliktuve</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Saglabā ekrāna ierakstu, lūdzu uzgaidiet...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Tā kā procesa laikā loga efekts ir atspējots, ieraksts ir jāpārtrauc</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekrānuzņēmums</translation>
    </message>
    <message>
        <source>The screenshot has been saved in the album</source>
        <translation>Ekrānuzņēmums saglabāts albumā</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Atsaukt</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Saglabāt</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Iziet</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Apskatīt</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Ieraksts pabeigts</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Saglabāt %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Ierakstīt</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Ekrāna ierakstīšana sāksies pēc %1 sekundēm</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Ievadiet tekstu šeit</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Sākt/Ekrānuzņēmums</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Iziet/Saglabāt</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Pielāgot izmēru</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Iestatījumi</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Ātrais sākums</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Loga ekrānuzņēmums</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Atlikt ekrānuzņēmumu</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Viss ekrānuzņēmums</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Iziet</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Saglabāt</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Taisnstūris</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Līnija</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Zīmulis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Teksts</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dzēst</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Atsaukt</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Palielināt augstumu augšā</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Palielināt augstumu lejā</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Palielināt platumu kreisajā pusē</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Palielināt platumu labajā pusē</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Samazināt augstumu augšā</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Samazināt augstumu lejā</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Samazināt platumu kreisajā pusē</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Samazināt platumu labajā pusē</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Palīdzība</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Rādīt saīsnes</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Skaņa</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Taustiņa nospiešana</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Sākt ierakstu</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Iestatījumi</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Sākt/Ierakstīt</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Pele</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screen Capture</source>
        <translation>Ekrāna ierakstīšana</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekrānuzņēmums</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Izpludināt</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mozaīka</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Ieslēgt skaņu</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofons</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Sistēmas skaņa</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Izslēgt skaņu</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Rādīt taustiņu nospiešanu</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Nerādīt taustiņu nospiešanu</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Ieslēgt kameru</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Izslēgt kameru</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Rādīt klikšķus</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Iestatījumi</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formāts:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>Kadri sekundē:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 kadri sekundē</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 kadri sekundē</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 kadri sekundē</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 kadri sekundē</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 kadri sekundē</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Taisnstūris</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Līnija</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Bulta</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Zīmulis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Teksts</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Saglabāt</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Darbavirsma</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Attēli</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mape</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formāts</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Starpliktuve</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Rādīt rādītāju</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Pele</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Rādīt Rādītāju</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>webm</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ogg</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>Atzimējiet ieraksta laukumu iekļaujoties %1*%2 lai iegūtu labāku video</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation>Iziet</translation>
    </message>
</context>
</TS>
